Model

Struct Model 

pub struct Model { /* private fields */ }
Main ONNX model container

Implementations

Source

impl Model

pub fn load_from_file<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Load ONNX model from a file path using memory mapping (mmap).

The parent directory of path is used to resolve external data files.

pub fn load_from_bytes(data: impl Into<Bytes>) -> Result<Self, Error>

Load ONNX model from byte buffer (e.g., Vec<u8>, Bytes, &'static [u8]).

Use Model::load_from_bytes_with_path if the model references external data files.

pub fn load_from_bytes_with_path<P: AsRef<Path>>( data: impl Into<Bytes>, path: P, ) -> Result<Self, Error>

Load ONNX model from byte buffer (e.g., Vec<u8>, Bytes, &'static [u8]) with a directory path for resolving external data files.

Note: path must be the folder/directory containing the external data files, not a file path. Use Model::load_from_bytes if the model contains no external data files.

pub fn graph(&self) -> &Graph

Reference to the root graph of the model

pub fn graph_mut(&mut self) -> &mut Graph

Mutable reference to the root graph of the model

pub fn into_graph(self) -> Graph

Consume the model and return the root graph

pub fn ir_version(&self) -> i64

Get IR version

pub fn producer_name(&self) -> Option<&str>

Get producer name

pub fn producer_version(&self) -> Option<&str>

Get producer version

pub fn domain(&self) -> Option<&str>

Get model domain

pub fn model_version(&self) -> Option<i64>

Get model version

pub fn doc_string(&self) -> Option<&str>

Get documentation string

pub fn metadata(&self) -> &HashMap<String, String>

Get custom metadata properties

pub fn opsets(&self) -> &HashMap<String, i64>

Get operator set imports (domain -> version)

pub fn default_opset_version(&self) -> Option<i64>

Get the imported opset version for the default ONNX domain (“”)