pub enum TensorData {
Raw(Bytes),
Strings(Vec<Bytes>),
F32(Vec<f32>),
F64(Vec<f64>),
I32(Vec<i32>),
I64(Vec<i64>),
U64(Vec<u64>),
}Expand description
Zero-copy owned tensor data
Variants
Raw(Bytes)
Strings(Vec<Bytes>)
F32(Vec<f32>)
F64(Vec<f64>)
I32(Vec<i32>)
I64(Vec<i64>)
U64(Vec<u64>)
Implementations
Sourceimpl TensorData
impl TensorData
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Total byte length across all variants
For Strings, returns the sum of all string element byte lengths.
If all Strings are empty, returns 0.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if data contains no elements
For Raw and numeric variants, equivalent to len() == 0.
For Strings, checks if the vector of string elements is empty.