Tensor

Struct Tensor 

pub struct Tensor { /* private fields */ }
An ONNX tensor with a name, shape, data type, and optional underlying data

Implementations

Source

impl Tensor

pub fn name(&self) -> Option<&str>

Tensor name

pub fn shape(&self) -> &[i64]

Tensor shape dimensions

pub fn data_type(&self) -> DataType

Tensor data type

pub fn has_data(&self) -> bool

Returns true if this tensor contains data.

This check does not trigger loading or memory-mapping of external files.

pub fn data(&self) -> Result<TensorDataRef<'_>, Error>

Borrow tensor data

  • All variants are returned without copying the underlying tensor data.
  • External data is loaded from disk if not already in memory.
pub fn into_data(self) -> Result<TensorData, Error>

Consume tensor and return owned data

  • All variants are returned without copying the underlying tensor data.
  • External data is loaded from disk if not already in memory.